@@ -488,7 +488,9 @@ class Issues(ImportCollectionMixin, Collection):
     path = '/{api_version}/issues/{id}'
     search_path = '/{api_version}/issues/_search'
     import_path = '/{api_version}/issues/_import'
+    unique_path = '/{api_version}/issues/_findByUnique'
     has_local_fields = True
+    date_format = '%Y-%m-%dT%H:%M:%S.%f%z'
 
     _fields = None
 
@@ -524,8 +526,12 @@ class Issues(ImportCollectionMixin, Collection):
             unique = kwargs.get('unique')
             if unique is not None:
                 try:
-                    return list(self.get_all(filter='unique:' + unique))[0]
-                except IndexError:
+                    return self._execute_request(
+                        self._connection.post,
+                        path=self.unique_path,
+                        params={'unique': unique},
+                    )
+                except exceptions.NotFound:
                     logger.error('Not found the issue by unique "%s"', unique)
             raise e
 
@@ -740,6 +746,20 @@ class Queues(Collection):
             path=queue._path + '/triggers',
         )
 
+    @injected_property
+    def macros(self, queue):
+        return self._execute_request(
+            self._connection.get,
+            path=queue._path + '/macros',
+        )
+
+    @injected_method
+    def check_permissions(self, queue, permission_code):
+        return self._execute_request(
+            self._connection.get,
+            path=queue._path + '/checkPermissions/{}'.format(permission_code),
+        )
+
 
 class QueueDefaultValues(Collection):
     """Extra get params = localized"""
@@ -776,6 +796,19 @@ class Triggers(Collection):
     _priority = 1
 
 
+class Macros(Collection):
+    path = '/{api_version}/queues/{queue}/macros/{id}'
+    fields = {
+        'id': None,
+        'self': None,
+        'queue': None,
+        'name': None,
+        'body': None,
+        'fieldChanges': None,
+    }
+    _priority = 1
+
+
 class IssueTransitions(Collection):
     """Extra get params = localized"""
     path = '/{api_version}/issues/{issue}/transitions/{id}'
@@ -1014,19 +1047,12 @@ class Worklog(Collection):
         )
 
 
-class IssueWorklog(Collection):
+class IssueWorklog(Collection, ImportCollectionMixin):
     path = '/{api_version}/issues/{issue}/worklog/{id}'
+    import_path = '/{api_version}/issues/{issue}/worklogs/_import'
     fields = Worklog.fields
     _priority = 1
 
-    def create(self, start, duration, comment=None):
-        assert 'issue' in self._vars
-        super(IssueWorklog, self).create(
-            start=start,
-            duration=duration,
-            comment=comment
-        )
-
 
 class LinkTypes(Collection):
     path = '/{api_version}/linktypes/{id}'
@@ -1100,6 +1126,9 @@ class Workflows(Collection):
         'self': None,
         'version': None,
         'xml': None,
+        'name': None,
+        'steps': [],
+        'initialAction': None,
     }
 
 
